@@ -674,7 +674,10 @@ _gnutls_x509_verify_certificate (const gnutls_x509_crt_t * certificate_list,
        * certificates can exist in a supplied chain.
        */
       if (!(flags & GNUTLS_VERIFY_ALLOW_ANY_X509_V1_CA_CRT))
-        flags &= ~(GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT);
+        {
+          flags &= ~(GNUTLS_VERIFY_ALLOW_X509_V1_CA_CRT);
+          flags |= GNUTLS_VERIFY_DO_NOT_ALLOW_X509_V1_CA_CRT;
+        }
       if ((ret =
            _gnutls_verify_certificate2 (certificate_list[i - 1],
                                         &certificate_list[i], 1, flags,
@@ -1004,15 +1007,15 @@ gnutls_x509_crl_verify (gnutls_x509_crl_t crl,
       }
   }
   
-  if (gnutls_x509_crl_get_this_update (crl) > now)
+  if (gnutls_x509_crl_get_this_update (crl) > now && verify)
     *verify |= GNUTLS_CERT_REVOCATION_DATA_ISSUED_IN_FUTURE;
     
-  if (gnutls_x509_crl_get_next_update (crl) < now)
+  if (gnutls_x509_crl_get_next_update (crl) < now && verify)
     *verify |= GNUTLS_CERT_REVOCATION_DATA_SUPERSEDED;
 
 
 cleanup:
-  if (*verify) *verify |= GNUTLS_CERT_INVALID;
+  if (verify) *verify |= GNUTLS_CERT_INVALID;
 
   _gnutls_free_datum (&crl_signed_data);
   _gnutls_free_datum (&crl_signature);
